From 4ddd3ec80cc0682a46c2d3fed137a5fa7657c5b0 Mon Sep 17 00:00:00 2001
From: toasted-nutbread <toasted-nutbread@users.noreply.github.com>
Date: Thu, 25 Mar 2021 21:40:27 -0400
Subject: Fix incorrect sorting (#1557)

* Sort by the maximum length of transformedText instead of deinflectedText

* Update docs

* Update tests
---
 docs/interfaces/dictionary-entry.ts | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'docs/interfaces')

diff --git a/docs/interfaces/dictionary-entry.ts b/docs/interfaces/dictionary-entry.ts
index 6aaafbf8..0b64908b 100644
--- a/docs/interfaces/dictionary-entry.ts
+++ b/docs/interfaces/dictionary-entry.ts
@@ -225,9 +225,9 @@ namespace Translation {
          */
         sourceTermExactMatchCount: number;
         /**
          * The maximum deinflected text length of a primary source.
          */
-        maxDeinflectedTextLength: number;
+        maxTransformedTextLength: number;
         /**
          * Headwords for the entry.
          */
@@ -225,9 +225,9 @@ namespace Translation {
         sourceTermExactMatchCount: number;
         /**
-         * The maximum deinflected text length of a primary source.
+         * The maximum length of the transformed text for all primary sources.
          */
-- 
cgit v1.2.3